package wusthelper.web.api.v2.dto.response.library;

import cn.wustlinghang.mywust.data.library.origin.BookSearchResult;
import cn.wustlinghang.mywust.data.library.parsed.BookDetail;
import cn.wustlinghang.mywust.data.library.parsed.BookHolding;
import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.Data;

import java.util.List;

@Data
@JsonInclude(JsonInclude.Include.NON_NULL)
public class BookDetailResponse {
    /**
     * 题名/责任者
     */
    private String bookNameAndAuth;

    /**
     * 出版发行项
     */
    private String publisher;

    /**
     * ISBN及定价
     */
    private String ISBN;

    /**
     * 内容简介
     */
    private String introduction;

    /**
     * 图片URL
     */
    private String imgUrl;

    /**
     * 是否已经收藏
     */
    private Integer isCollection;

    /**
     * 租借信息
     */
    private List<BookHoldingInfo> list;

    public static BookDetailResponse from(BookDetail bookDetail) {
        BookDetailResponse bookDetailResponse = new BookDetailResponse();

        var extraInfo = bookDetail.getExtraInfoMap();
        bookDetailResponse.setBookNameAndAuth(extraInfo.get("题名/责任者"));
        bookDetailResponse.setPublisher(extraInfo.get("出版发行项"));

        bookDetailResponse.setISBN(bookDetail.getIsbn());
        bookDetailResponse.setIntroduction(bookDetail.getIntroduction());
        bookDetailResponse.setIsCollection(0);
        bookDetailResponse.setImgUrl(bookDetail.getCoverUrl());
//        bookDetailResponse.setList();

        return bookDetailResponse;
    }

    @Data
    public static class BookHoldingInfo {
        /**
         * 索书号
         */
        private String callNo;
        /**
         * 条号码
         */
        private String barCode;
        /**
         * 馆藏地
         */
        private String location;
        /**
         * 是否可借
         */
        private String status;

        public static BookHoldingInfo from(BookHolding bookHolding) {
            BookHoldingInfo bookHoldingInfo = new BookHoldingInfo();
            bookHoldingInfo.setCallNo(bookHolding.getCallNumber());
            bookHoldingInfo.setBarCode(bookHolding.getBarCode());
            bookHoldingInfo.setLocation(bookHolding.getLocation());
            bookHoldingInfo.setStatus(bookHolding.getStatus());

            return bookHoldingInfo;
        }
    }
}
