package wusthelper.web.api.v2.module.library;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import wusthelper.web.annotation.RequireToken;
import wusthelper.web.api.v2.TokenTool;
import wusthelper.web.api.v2.code.V2ResponseCode;
import wusthelper.web.api.v2.dto.response.library.CurrentRentResponse;
import wusthelper.web.api.v2.dto.response.library.RentHistoryResponse;
import wusthelper.web.response.Response;
import wusthelper.web.service.campus.library.LibraryPersonalService;

import java.util.ArrayList;
import java.util.List;

@RequireToken
@RestController
@RequestMapping("/v2/lib")
public class LibraryPersonalController {

    private final LibraryPersonalService service;

    public LibraryPersonalController(LibraryPersonalService service) {
        this.service = service;
    }

    /**
     * 获取当前借阅信息
     *
     * @param token
     * @return
     */
    @GetMapping(path = "/get-current-rent", produces = {"application/json"})
    public Response<List<CurrentRentResponse>> getCurrentRent(@RequestHeader(value = "Token") String token) {
        String stuNum = TokenTool.getStudentNumber(token);
        var resultList = service.getCurrentLoan(stuNum, 0, 30).getData();
        var responseData = new ArrayList<CurrentRentResponse>(resultList.size());
        for (var result : resultList) {
            responseData.add(CurrentRentResponse.from(result));
        }

        return Response.success(V2ResponseCode.LIB_GETCURRENTRENT_SUC.getCode(), responseData);
    }

    /**
     * 获取历史借阅信息
     *
     * @param token
     * @return
     */
    @GetMapping(path = "/get-rent-history", produces = {"application/json"})
    public Response<List<RentHistoryResponse>> getRentHistory(@RequestHeader(value = "Token") String token) {
        String stuNum = TokenTool.getStudentNumber(token);
        var resultList = service.getLoanHistory(stuNum, 0, 30).getData();
        var responseData = new ArrayList<RentHistoryResponse>(resultList.size());
        for (var result : resultList) {
            responseData.add(RentHistoryResponse.from(result));
        }

        return Response.success(V2ResponseCode.LIB_GETRENTHISTORY_SUC.getCode(), responseData);
    }
}
