package wusthelper.web.service.campus.library;

import cn.wustlinghang.mywust.data.library.PagingResult;
import cn.wustlinghang.mywust.data.library.origin.BookSearchResult;
import cn.wustlinghang.mywust.data.library.parsed.BookDetail;
import cn.wustlinghang.mywust.data.library.parsed.BookHolding;
import org.springframework.stereotype.Service;
import wusthelper.code.ServiceCode;
import wusthelper.web.exception.ServiceException;
import wusthelper.web.rpc.http.library.LibraryBookCoverImageRemote;
import wusthelper.web.rpc.http.library.LibraryBookDetailRemote;
import wusthelper.web.rpc.http.library.LibraryBookHoldingRemote;
import wusthelper.web.rpc.http.library.LibrarySearchRemote;

import java.util.*;

@Service
public class LibraryPublicService {
    private final LibraryBookCoverImageRemote bookCoverImageRemote;
    private final LibraryBookDetailRemote bookDetailRemote;
    private final LibraryBookHoldingRemote bookHoldingRemote;
    private final LibrarySearchRemote searchRemote;

    public LibraryPublicService(LibraryBookCoverImageRemote bookCoverImageRemote,
                                LibraryBookDetailRemote bookDetailRemote,
                                LibraryBookHoldingRemote bookHoldingRemote,
                                LibrarySearchRemote searchRemote) {

        this.bookCoverImageRemote = bookCoverImageRemote;
        this.bookDetailRemote = bookDetailRemote;
        this.bookHoldingRemote = bookHoldingRemote;
        this.searchRemote = searchRemote;
    }

    public String getBookCoverImage(String isbn) {
        var rpcResp = bookCoverImageRemote.agent(isbn);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }

    public Map<String, List<String>> getBookCoverImageBatch(Collection<String> isbn) {
        if (isbn.isEmpty()) {
            return new HashMap<>();
        }

        StringJoiner stringJoiner = new StringJoiner(",");
        for (var i : isbn) {
            stringJoiner.add(i);
        }

        var rpcResp = bookCoverImageRemote.batch(stringJoiner.toString());
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }

    public BookDetail getBookDetail(String id) {
        var rpcResp = bookDetailRemote.get(id);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }

    public List<BookHolding> getBookHolding(String id) {
        var rpcResp = bookHoldingRemote.get(id);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }

    public PagingResult<List<BookSearchResult>> searchBooks(String keyword, int page, int pageSize) {
        var rpcResp = searchRemote.get(keyword, page, pageSize);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }
}
